==> haskell-chunked-data-0.3.1-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-chunked-data.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: chunked-data
version: 0.3.1
id: chunked-data-0.3.1-BXy0HARKbHE67PnniqPIVl
key: chunked-data-0.3.1-BXy0HARKbHE67PnniqPIVl
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/snoyberg/mono-traversable#readme
synopsis: Typeclasses for dealing with various chunked data representations
description:
    See docs and README at <http://www.stackage.org/package/chunked-data>
category: Data
abi: 8bc3f38debb83f0ba69db63ae872829c
exposed: True
exposed-modules:
    Data.Builder Data.ChunkedZip Data.IOData
hidden-modules: Paths_chunked_data
import-dirs: /usr/lib/ghc-8.4.3/site-local/chunked-data-0.3.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/chunked-data-0.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/chunked-data-0.3.1
hs-libraries: HSchunked-data-0.3.1-BXy0HARKbHE67PnniqPIVl
depends:
    base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0 text-1.2.3.0
    transformers-0.5.5.0 vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
haddock-interfaces: /usr/share/doc/haskell-chunked-data/html/chunked-data.haddock
haddock-html: /usr/share/doc/haskell-chunked-data/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-chunked-data-0.3.1-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-chunked-data.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: chunked-data
version: 0.3.1
id: chunked-data-0.3.1-9J4hf7bNkG1L6Tc7Bc8g7e
key: chunked-data-0.3.1-9J4hf7bNkG1L6Tc7Bc8g7e
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/snoyberg/mono-traversable#readme
synopsis: Typeclasses for dealing with various chunked data representations
description:
    See docs and README at <http://www.stackage.org/package/chunked-data>
category: Data
abi: 8458e52408cb5a0cc9524b2205593dc8
exposed: True
exposed-modules:
    Data.Builder Data.ChunkedZip Data.IOData
hidden-modules: Paths_chunked_data
import-dirs: /usr/lib/ghc-8.6.1/site-local/chunked-data-0.3.1
library-dirs: /usr/lib/ghc-8.6.1/site-local/chunked-data-0.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/chunked-data-0.3.1
hs-libraries: HSchunked-data-0.3.1-9J4hf7bNkG1L6Tc7Bc8g7e
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1 text-1.2.3.1
    transformers-0.5.5.0 vector-0.12.0.1-BKWaeB2IPwRDyZEP11mv5m
haddock-interfaces: /usr/share/doc/haskell-chunked-data/html/chunked-data.haddock
haddock-html: /usr/share/doc/haskell-chunked-data/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
